==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/directory/messages/de/base.php <==
<?php
return array (
  '<b>Nobody wrote something yet.</b><br>Make the beginning and post something...' => '<strong>Bisher hat niemand etwas geschrieben.</strong><br />Mache den Anfang und schreibe etwas...',
  '<b>There are no profile posts yet!</b>' => '<b>Bisher existieren keine Profil-Beiträge!</b>',
  '<strong>Directory</strong> menu' => '<strong>Verzeichnis-</strong>Menü',
  '<strong>Group</strong> members - {group}' => '<strong>Gruppen</strong> Mitglieder - {group}',
  '<strong>Group</strong> stats' => '<strong>Gruppen-</strong>Statistiken',
  '<strong>Member</strong> Group Directory' => '<strong>Mitglieder</strong>gruppen-Verzeichnis',
  '<strong>Member</strong> directory' => '<strong>Mitglieder-</strong>Verzeichnis',
  '<strong>Member</strong> stats' => '<strong>Mitglieder</strong> Statistiken',
  '<strong>New</strong> people' => '<strong>Neue</strong> Leute',
  '<strong>New</strong> spaces' => '<strong>Neue</strong> Spaces',
  '<strong>Space</strong> directory' => '<strong>Space-</strong>Verzeichnis',
  '<strong>Space</strong> stats' => '<strong>Space</strong> Statistiken',
  'Access directory' => 'Verzeichniszugriff',
  'Average members' => 'Durchschnittliche Mitgliederanzahl',
  'Can access the directory section.' => 'Kann nicht auf den Verzeichnisabschnitt zugreifen.',
  'Directory' => 'Verzeichnis',
  'Follows somebody' => 'Folgt jemandem',
  'Groups' => 'Gruppen',
  'Members' => 'Mitglieder',
  'Most members' => 'Die meisten Mitglieder',
  'No members found!' => 'Keine Mitglieder gefunden!',
  'No spaces found!' => 'Keine Spaces gefunden!',
  'Online right now' => 'Jetzt online',
  'Private spaces' => 'Private Spaces',
  'Search' => 'Suchen',
  'See all' => 'Zeige alle',
  'Send invite' => 'Einladung/en versenden',
  'Spaces' => 'Spaces',
  'This group has no members yet.' => 'Diese Gruppe hat bislang keine Mitglieder.',
  'Top Group' => 'Top Gruppen',
  'Total groups' => 'Gruppen insgesamt',
  'Total spaces' => 'Spaces insgesamt',
  'Total users' => 'Benutzer insgesamt',
  'User profile posts' => 'Profilbeiträge',
  'You are a member of this space' => 'Du bist Mitglied dieses Space',
  'search for members' => 'Suche nach Mitgliedern',
  'search for spaces' => 'Suche nach Spaces',
  'show all members' => 'zeige alle Mitglieder',
);

==> humhub-1.4.1.tar.gz: humhub-1.4.1/protected/humhub/modules/directory/messages/de/base.php <==
<?php
return array (
  '<b>Nobody has written anything yet.</b><br>Post to get things started...' => '<strong>Bisher hat niemand etwas geschrieben.</strong><br />Mache den Anfang und schreibe etwas...',
  '<b>There are no profile posts yet!</b>' => '<b>Bisher existieren keine Profil-Beiträge!</b>',
  '<strong>Directory</strong> menu' => '<strong>Verzeichnis-</strong>Menü',
  '<strong>Group</strong> members - {group}' => '<strong>Gruppen-</strong>Mitglieder - {group}',
  '<strong>Group</strong> stats' => '<strong>Gruppen-</strong>Statistiken',
  '<strong>Member</strong> Group Directory' => '<strong>Mitglieder</strong>gruppen-Verzeichnis',
  '<strong>Member</strong> directory' => '<strong>Mitglieder-</strong>Verzeichnis',
  '<strong>Member</strong> stats' => '<strong>Mitglieder-</strong>Statistiken',
  '<strong>New</strong> people' => '<strong>Neue</strong> Leute',
  '<strong>New</strong> spaces' => '<strong>Neue</strong> Spaces',
  '<strong>Space</strong> directory' => '<strong>Space-</strong>Verzeichnis',
  '<strong>Space</strong> stats' => '<strong>Space-</strong>Statistiken',
  'Access directory' => 'Verzeichniszugriff',
  'Average members' => 'Durchschnittliche Mitgliederanzahl',
  'Can access the directory section.' => 'Kann auf den Verzeichnisbereich zugreifen.',
  'Directory' => 'Verzeichnis',
  'Follows somebody' => 'Folgt jemandem',
  'Groups' => 'Gruppen',
  'Members' => 'Mitglieder',
  'Most members' => 'Meiste Mitglieder',
  'No members found!' => 'Keine Mitglieder gefunden!',
  'No spaces found!' => 'Keine Spaces gefunden!',
  'Online right now' => 'Jetzt online',
  'Private spaces' => 'Private Spaces',
  'Search' => 'Suchen',
  'See all' => 'Zeige alle',
  'Send invite' => 'Einladung/en versenden',
  'Spaces' => 'Spaces',
  'This group has no members yet.' => 'Diese Gruppe hat bislang keine Mitglieder.',
  'Top Group' => 'Top Gruppen',
  'Total groups' => 'Gruppen insgesamt',
  'Total spaces' => 'Spaces insgesamt',
  'Total users' => 'Benutzer insgesamt',
  'User profile posts' => 'Profilbeiträge',
  'You are a member of this space' => 'Du bist Mitglied dieses Space',
  'search for members' => 'Suche nach Mitgliedern',
  'search for spaces' => 'Suche nach Spaces',
  'show all members' => 'zeige alle Mitglieder',
);
